@@ -309,25 +309,25 @@ class S1(Pulse):
 
         _, _, t, x, y, z, n_photons, recoil_type, *rest = [
             np.array(v).reshape(-1) for v in zip(*instruction)]
-
         positions = np.array([x, y, z]).T  # For map interpolation
         n_photons = self.get_n_photons(n_photons=n_photons,
                                        positions=positions,
                                        s1_light_yield_map=self.resource.s1_light_yield_map,
                                        config=self.config)
-
-        self._photon_timings = self.photon_timings(t=t,
-                                                   n_photons=n_photons, 
-                                                   recoil_type=recoil_type,
-                                                   config=self.config,
-                                                   phase=self.phase)
-
         # The new way interpolation is written always require a list
         self._photon_channels = self.photon_channels(positions=positions,
                                                      n_photons=n_photons,
                                                      config=self.config, 
                                                      s1_pattern_map=self.resource.s1_pattern_map)
 
+        self._photon_timings = self.photon_timings(t=t,
+                                                   n_photons=n_photons, 
+                                                   recoil_type=recoil_type,
+                                                   config=self.config,
+                                                   phase=self.phase,
+                                                   channels=self._photon_channels,
+                                                   positions = positions,
+                                                   resource=self.resource )
         super().__call__()
 
     @staticmethod
@@ -373,26 +373,41 @@ class S1(Pulse):
         return _photon_channels
 
     @staticmethod
-    def photon_timings(t, n_photons, recoil_type, config, phase):
+    def photon_timings(t, n_photons, recoil_type, config, phase, channels=None,positions=None,resource=None):
         """Calculate distribution of photon arrival timnigs
         :param t: 1d array of ints
         :param n_photons: 1d array of ints
         :param recoil_type: 1d array of ints
         :param config: dict wfsim config
         :param phase: str "liquid"
-
+        :param channels: list of photon hit channels 
+        :params positions: nx3 array of true XYZ positions from instruction
+        :parans resource: pointer to resources class of wfsim that contains s1 timing splines
         returns photon timing array"""
         _photon_timings = np.repeat(t, n_photons)
         if len(_photon_timings) == 0:
             return _photon_timings.astype(np.int64)
-        
         if (config['s1_model_type'] == 'simple' and
                 np.isin(recoil_type, NestId._ALL).all()):
             # Simple S1 model enabled: use it for ER and NR.
             _photon_timings += np.random.exponential(config['s1_decay_time'], len(_photon_timings)).astype(np.int64)
             _photon_timings += np.random.normal(0, config['s1_decay_spread'], len(_photon_timings)).astype(np.int64)
             return _photon_timings
-
+        if (config['s1_model_type'] == 'simplespline' and
+                np.isin(recoil_type, NestId._ALL).all()):
+            counts_start = 0
+            for i, counts in enumerate(n_photons):  
+                _prop_time = S1.spline_delay(counts_start = counts_start, 
+                                               counts      = counts, 
+                                               channels    = channels,
+                                               position    = positions[i],
+                                               config      = config,       
+                                               splines     = resource.s1_time_splines)
+                _photon_timings[counts_start:counts_start+counts]+=_prop_time.round().astype(np.int64)
+                counts_start += counts
+            return _photon_timings
+        
+        _photon_timings = np.repeat(t, n_photons)
         counts_start = 0
         for i, counts in enumerate(n_photons):
             for k in vars(NestId):
@@ -411,6 +426,42 @@ class S1(Pulse):
             counts_start += counts
         return _photon_timings
 
+    @staticmethod
+    def spline_delay(counts_start, counts, channels, position, config, splines):
+        """Function gettting times from s1 timing splines:
+        
+        :param counts_start: first count corresponding to current instruction
+        :param counts: number of counts corresponding to current instruction
+        :param position: 1x3 array for XYZ position of current instruction
+        :param config: current configuration of wfsim
+        :param splines: pointer to s1 timing splines from resources
+        """
+        extra_times = np.zeros(counts)
+        
+        # interpolation functions inside make resorting and result in sorted times
+        # argsort is used to avoid this issue 
+        ## doing top arrays
+        _top_bool = channels[counts_start:counts_start+counts]<(config['n_top_pmts'])
+        _n_top_hit = np.sum(_top_bool)
+        _top_times = np.zeros(_n_top_hit)
+        _top_rng = np.random.uniform(0,1,size=_n_top_hit)
+        _top_argsort = _top_rng.argsort()
+        _top_times[_top_argsort] = splines['top'](position[2], _top_rng[_top_argsort] )[:,0]
+        ### doing bottom array
+        _bottom_bool = channels[counts_start:counts_start+counts]>=(config['n_top_pmts'])
+        _n_bottom_hit = np.sum(_bottom_bool)     
+        _bottom_times = np.zeros(_n_bottom_hit)  
+        _bottom_rng = np.random.uniform(0,1,size=_n_bottom_hit)
+        _bottom_argsort = _bottom_rng.argsort()
+        _bottom_times[_bottom_argsort] = splines['bottom'](position[2],
+                                                                   _bottom_rng[_bottom_argsort] )[:,0]
+            
+        ### Addting propagation/scintillation delay to final times
+        extra_times[_top_bool] = _top_times
+        extra_times[_bottom_bool] = _bottom_times
+
+        return(extra_times)     
+        
     @staticmethod
     def alpha(size, config, phase):
         """  Calculate S1 photon timings for an alpha decay. Neglible recombination time, not validated
@@ -583,12 +634,10 @@ class S2(Pulse):
         
         returns array of floats (mean expectation) 
         """
-        if config['detector'] == 'XENONnT':
-            sc_gain = np.squeeze(resource.s2_light_yield_map(positions), axis=-1) \
-                * config['s2_secondary_sc_gain']
-        elif config['detector'] == 'XENON1T':
-            sc_gain = resource.s2_light_yield_map(positions) \
-                * config['s2_secondary_sc_gain']
+        # sc gain should has the unit of pe / electron, here we divide 1 + dpe to get nphoton / electron
+        sc_gain = resource.s2_correction_map(positions) \
+                * config['s2_secondary_sc_gain'] / (1 + config['p_double_pe_emision'])
+
         return sc_gain
 
     @staticmethod
