@@ -56,7 +56,7 @@ class Resource:
                 'photon_area_distribution': 'XENON1T_spe_distributions.csv',
                 's1_light_yield_map': 'XENON1T_s1_xyz_ly_kr83m_SR1_pax-680_fdc-3d_v0.json',
                 's1_pattern_map': 'XENON1T_s1_xyz_patterns_interp_corrected_MCv2.1.0.json.gz',
-                's2_light_yield_map': 'XENON1T_s2_xy_ly_SR1_v2.2.json',
+                's2_correction_map': 'XENON1T_s2_xy_ly_SR1_v2.2.json',
                 's2_pattern_map': 'XENON1T_s2_xy_patterns_top_corrected_MCv2.1.0.json.gz',
                 'photon_ap_cdfs': 'x1t_pmt_afterpulse_config.pkl.gz',
                 'fdc_3d': 'XENON1T_FDC_SR1_data_driven_time_dependent_3d_correction_tf_nn_part1_v1.json.gz',
@@ -69,12 +69,14 @@ class Resource:
                 'photon_area_distribution': 'XENONnT_spe_distributions_20210305.csv',
                 's1_pattern_map': 'XENONnT_s1_xyz_patterns_LCE_corrected_qes_MCva43fa9b_wires.pkl',
                 's2_pattern_map': 'XENONnT_s2_xy_patterns_LCE_corrected_qes_MCva43fa9b_wires.pkl',
+                's2_correction_map': 'XENONnT_s2_xy_correction_corrected_qes_MCva43fa9b_wires.json.gz',
                 'photon_ap_cdfs': 'XENONnT_pmt_afterpulse_config_012605.json.gz',
                 's2_luminescence': 'XENONnT_GARFIELD_B1d5n_C30n_G1n_A6d5p_T1d5n_PMTs1d5n_FSR0d95n.npz',
                 'gas_gap_map': 'gas_gap_warping_map_January_2021.pkl',
                 'ele_ap_pdfs': 'x1t_se_afterpulse_delaytime.pkl.gz',
                 'noise_file': 'x1t_noise_170203_0850_00_small.npz',
                 'field_dependencies_map': '',
+                's1_time_spline': '',
              })
         elif config['detector'] == 'XENONnT_neutron_veto':
             files.update({
@@ -142,12 +144,10 @@ class Resource:
                     files[k] = raw_url
             log.debug(f'Downloaded {k} successfully')
 
-        self.photon_area_distribution = straxen.get_resource(files['photon_area_distribution'], fmt='csv')
-
-        if config['detector'] == 'XENON1T':
+        if config.get('detector', 'XENONnT') == 'XENON1T':
             self.s1_pattern_map = make_map(files['s1_pattern_map'], fmt='json.gz')
             self.s1_light_yield_map = make_map(files['s1_light_yield_map'], fmt='json')
-            self.s2_light_yield_map = make_map(files['s2_light_yield_map'], fmt='json')
+            self.s2_correction_map = make_map(files['s2_correction_map'], fmt='json')
             self.s2_pattern_map = make_map(files['s2_pattern_map'], fmt='json.gz')
             self.fdc_3d = make_map(files['fdc_3d'], fmt='json.gz')
 
@@ -159,6 +159,10 @@ class Resource:
             if config.get('enable_pmt_afterpulses', False):
                 self.uniform_to_pmt_ap = straxen.get_resource(files['photon_ap_cdfs'], fmt='pkl.gz')
 
+            # Electron After Pulses
+            if config.get('enable_electron_afterpulses', False):
+                self.uniform_to_ele_ap = straxen.get_resource(files['ele_ap_pdfs'], fmt='pkl.gz')
+
         elif config.get('detector', 'XENONnT') == 'XENONnT':
             self.s1_pattern_map = make_map(files['s1_pattern_map'], fmt='pkl')
             if isinstance(self.s1_pattern_map, DummyMap):
@@ -170,13 +174,7 @@ class Resource:
                 self.s1_light_yield_map = lymap
 
             self.s2_pattern_map = make_map(files['s2_pattern_map'], fmt='pkl')
-            if isinstance(self.s2_pattern_map, DummyMap):
-                self.s2_light_yield_map = self.s2_pattern_map.reduce_last_dim()
-            else:
-                lymap = deepcopy(self.s2_pattern_map)
-                lymap.data['map'] = np.sum(lymap.data['map'][:][:], axis=2, keepdims=True)
-                lymap.__init__(lymap.data)
-                self.s2_light_yield_map = lymap
+            self.s2_correction_map = make_map(files['s2_correction_map'], fmt='json.gz')
 
             # Garfield luminescence timing samples
             if config.get('s2_luminescence_model', False) == 'garfield':
@@ -209,8 +207,15 @@ class Resource:
             if config.get('enable_pmt_afterpulses', False):
                 self.uniform_to_pmt_ap = straxen.get_resource(files['photon_ap_cdfs'], fmt='json.gz')
 
-        elif config.get('detector') == 'XENONnT_neutron_veto':
+            # S1 photon timing splines
+            if config.get('s1_time_spline', False):
+                self.s1_time_splines = straxen.get_resource(files['s1_time_spline'], fmt='pkl')
 
+            # Electron After Pulses
+            if config.get('enable_electron_afterpulses', False):
+                self.uniform_to_ele_ap = straxen.get_resource(files['ele_ap_pdfs'], fmt='pkl.gz')
+
+        elif config.get('detector', 'XENONnT') == 'XENONnT_neutron_veto':
             # Neutron veto PMT QE as function of wavelength
             if config.get('neutron_veto', False):
                 self.nv_pmt_qe = straxen.get_resource(files['nv_pmt_qe'], fmt='json')
@@ -218,10 +223,6 @@ class Resource:
         # SPE area distributions
         self.photon_area_distribution = straxen.get_resource(files['photon_area_distribution'], fmt='csv')
 
-        # Electron After Pulses compressed, haven't figure out how pkl.gz works
-        if config.get('enable_electron_afterpulses', False):
-            self.uniform_to_ele_ap = straxen.get_resource(files['ele_ap_pdfs'], fmt='pkl.gz')
-
         # Noise sample
         if config.get('enable_noise', False):
             self.noise_data = straxen.get_resource(files['noise_file'], fmt='npy')['arr_0'].flatten()
@@ -248,7 +249,7 @@ def make_map(map_file, fmt='text'):
         raise TypeError("Can't handle map_file except a string or a list")
 
 
-class DummyMap(object):
+class DummyMap:
     """Return constant results
         the length match the length of input
         but from the second dimensions the shape is user defined input
@@ -256,7 +257,7 @@ class DummyMap(object):
     def __init__(self, const, shape=()):
         self.const = const
         self.shape = shape
-        
+
     def __call__(self, x, **kwargs):
         shape = [len(x)] + list(self.shape)
         return np.ones(shape) * self.const
