@@ -521,7 +521,8 @@ class RawRecordsFromFax1T(RawRecordsFromFaxNT):
     strax.Option('fax_config_nveto', default=None, track=True,),
     strax.Option('fax_config_override_nveto', default=None, track=True,
                  help='Dictionary with configuration option overrides'),
-    strax.Option('gain_model_nv', default=('to_pe_constant', 0.01), track=False),
+    strax.Option('gain_model_nv', track=True,
+                 help='nveto gain model, provided by context'),
     strax.Option('targets', default=('tpc',), track=False,
                  help='tuple with what data to simulate (tpc, nveto or both)')
 )
@@ -714,17 +715,22 @@ class RawRecordsFromMcChain(SimulatorPlugin):
         chunk = {}
         for data_type in self.provides:
             if 'nv' in data_type:
-                chunk[data_type] = self.chunk(
-                    start=self.sim_nv.chunk_time_pre,
-                    end=self.sim_nv.chunk_time,
-                    data=result_nv[data_type.strip('_nv')],
-                    data_type=data_type)
+                if 'nveto' in self.config['targets']:
+                  chunk[data_type] = self.chunk(start=self.sim_nv.chunk_time_pre,
+                                                end=self.sim_nv.chunk_time,
+                                                data=result_nv[data_type.strip('_nv')],
+                                                data_type=data_type)
+                #If nv is not one of the targets just return an empty chunk
+                else:
+                  chunk[data_type] = self.chunk(start=self.sim.chunk_time_pre,
+                                                end=self.sim.chunk_time,
+                                                data=np.array([]),
+                                                data_type=data_type)
             else:
-                chunk[data_type] = self.chunk(
-                    start=self.sim.chunk_time_pre,
-                    end=self.sim.chunk_time,
-                    data=result[data_type],
-                    data_type=data_type)
+                chunk[data_type] = self.chunk(start=self.sim.chunk_time_pre,
+                                              end=self.sim.chunk_time,
+                                              data=result[data_type],
+                                              data_type=data_type)
 
         self._sort_check([chunk[data_type].data for data_type in self.provides])
 
